Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/optwps/__init__.py | (no class) | 8 | 2 | 0 | 0 | 0 | 75%
src/optwps/optwps.py | ROIGenerator | 25 | 0 | 0 | 10 | 0 | 100%
src/optwps/optwps.py | CMWriterUnpacker | 11 | 2 | 0 | 2 | 0 | 85%
src/optwps/optwps.py | WPS | 124 | 10 | 0 | 54 | 8 | 90%
src/optwps/optwps.py | (no class) | 41 | 20 | 0 | 4 | 1 | 49%
src/optwps/utils.py | (no class) | 23 | 2 | 0 | 6 | 1 | 90%
tests/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
tests/conftest.py | (no class) | 63 | 0 | 0 | 6 | 0 | 100%
tests/test_multiple_outputs.py | (no class) | 86 | 0 | 0 | 18 | 1 | 99%
tests/test_optwps.py | (no class) | 147 | 9 | 0 | 46 | 11 | 90%
Total |  | 528 | 45 | 0 | 146 | 22 | 90%

No items found using the specified filter.